@@ -22,5 +22,10 @@ class MascaraIpaddressController:
     def get_by_ipaddress(self, ipaddress: str) -> dict:
         return MascaraIpaddressService().get_mascara_ipaddress(ipaddress).as_dict()
 
+    def get_by_search_criteria(self, search_criteria: str) -> dict:
+        return (
+            MascaraIpaddressService().get_by_search_criteria(search_criteria).as_dict()
+        )
+
     def delete_by_ipaddress(self, ipaddress: str) -> dict:
         return MascaraIpaddressService().delete_mascara_ipaddress(ipaddress)
