@@ -21,5 +21,8 @@ class PauseReasonController:
     def get_by_pause_code(self, pause_code: str) -> dict:
         return PauseReasonService().get_pause_reason(pause_code).as_dict()
 
+    def get_by_search_criteria(self, search_criteria: str) -> dict:
+        return PauseReasonService().get_by_search_criteria(search_criteria).as_dict()
+
     def delete_by_pause_code(self, pause_code: str) -> dict:
         return PauseReasonService().delete_pause_reason(pause_code)
