@@ -18,5 +18,8 @@ class QueueStatusController:
     def get_by_status_code(self, status_code: str) -> dict:
         return QueueStatusService().get_queue_status(status_code).as_dict()
 
+    def get_by_search_criteria(self, search_criteria: str) -> dict:
+        return QueueStatusService().get_by_search_criteria(search_criteria).as_dict()
+
     def delete_by_status_code(self, status_code: str) -> dict:
         return QueueStatusService().delete_queue_status(status_code)
